@@ -40,7 +40,9 @@ class TokenToTokenMapper:
                 token_map = [str.lower(token) for token in token_map]
             token_map = list(set(token_map))
 
-            for pattern in token_map:
-                text_copy = regex.sub(pattern, token_key, text_copy)
+            # sort in decending order to captcher longer patterns first
+            token_map.sort(key=lambda x: len(x), reverse=True)
 
+            for pattern in token_map:
+                text_copy = regex.sub('[\s]' + pattern + '[\s]', f" {token_key} ", text_copy)
         return text_copy
