@@ -49,7 +49,8 @@ from seetm.shared.exceptions.io import (
     NLUFileNotFoundException,
     InvalidFileExtensionException,
     FileSizeInspectingException,
-    EvalFileNotFoundException, YAMLFileWriteException,
+    EvalFileNotFoundException,
+    YAMLFileWriteException,
 )
 
 logger = logging.getLogger(__name__)
